{% extends "wiki/article.html" %} {% load wiki_tags i18n humanize %} {% block wiki_pagetitle %}{% trans "History of" %} "{{ attachment.current_revision.get_filename }}"{% endblock %} {% block wiki_contents_tab %}

## {% trans "History of" %} "{{ attachment.current_revision.get_filename }}"

{% trans "Date" %} | {% trans "User" %} | {% trans "Description" %} | {% trans "File" %} | {% trans "Size" %} | {% trans "Action" %}
--- | --- | --- | --- | --- | ---
{% for revision in revisions %}
{{ revision.created }} {% if revision.deleted %}{% trans "deleted" %}{% endif %} | {% include "wiki/includes/revision_info.html" with revision=attachment.current_revision hidedate=1 hidenumber=1 %} | {{ revision.description|default:_("No description")|safe }} | {{ revision.get_filename }} | {{ revision.get_size|filesizeformat }} | {% csrf_token %} {% trans "Download" %} {% if revision.attachment.article|can_write:user %} {% trans "Use this!" %} {% endif %}
{% endfor %}

{% trans "Go back" %} {% endblock %}